﻿using data.Exception;
using data.RemoteData;
using data.RemoteData.DAO;
using domain.Models;
using Microsoft.EntityFrameworkCore;

namespace data.Repository
{
    public class SQLUserRepositoryImpl : IUserRepository
    {
        private readonly RemoteDatabaseContext _remoteDatabaseContext;

        public SQLUserRepositoryImpl(RemoteDatabaseContext remoteDatabaseContext)
        {
            _remoteDatabaseContext = remoteDatabaseContext;
        }

        
        public IEnumerable<UserLocalEnity> GetAllUsers => _remoteDatabaseContext.Users
            .Select(u => new UserLocalEnity
            {
                Guid = u.Guid,
                FIO = u.FIO,
                GroupID = u.GroupID
            })
            .ToList();

        public bool RemoveUserByGuid(Guid userGuid)
        {
            var user = _remoteDatabaseContext.Users.FirstOrDefault(u => u.Guid == userGuid);
            if (user == null) throw new UserNotFoundException(userGuid);

            _remoteDatabaseContext.Users.Remove(user);
            _remoteDatabaseContext.SaveChanges(); 
            return true;
        }

        public UserLocalEnity? UpdateUser(UserLocalEnity user)
        {
            var existingUser = _remoteDatabaseContext.Users.FirstOrDefault(u => u.Guid == user.Guid);
            if (existingUser == null) throw new UserNotFoundException(user.Guid);

            existingUser.FIO = user.FIO;
            existingUser.GroupID = user.GroupID;
            _remoteDatabaseContext.SaveChanges(); 

            // Возвращаем обновленный объект UserLocalEnity
            return new UserLocalEnity
            {
                Guid = existingUser.Guid,
                FIO = existingUser.FIO,
                GroupID = existingUser.GroupID
            };
        }

        // Дополнительный метод для DAO, если требуется
        public IEnumerable<RemoteData.DAO.UserDao> GetAllUsersDao => _remoteDatabaseContext.Users.ToList();

        public List<UserDao> GetUserNames()
        {
            return _remoteDatabaseContext.Users
                .Select(u => new UserDao { Guid = u.Guid, FIO = u.FIO })
                .ToList();
        }


        public UserDao GetUserInfo(Guid userGuid)
        {
            return _remoteDatabaseContext.Users
                .Include(u => u.Group)
                .FirstOrDefault(u => u.Guid == userGuid);
        }

        public bool AddUser(UserDao user)
        {
            try
            {
               
                var userDao = new UserDao
                {
                    Guid = user.Guid,
                    FIO = user.FIO,
                    GroupID = user.GroupID // Привязываем к группе
                };

                // Добавляем пользователя в контекст базы данных
                _remoteDatabaseContext.Users.Add(userDao);
                _remoteDatabaseContext.SaveChanges(); // Сохраняем изменения

                return true;
            }
            catch (System.Exception ex)
            {
                // Логирование ошибки (при необходимости)
                Console.WriteLine($"Ошибка при добавлении пользователя: {ex.Message}");
                return false;
            }
        }


    }
}
